@@ -9,11 +9,14 @@ import random
 import datetime
 import time
 import requests
+import pkg_resources
 from uuid import UUID
 import logging
 
 logger = logging.getLogger(__name__)
 
+# We want 4 second timeout for HTTP requests
+HTTP_TIMEOUT = 4.0
 _requests_session_instance = None
 
 
@@ -93,9 +96,11 @@ def is_valid_uuid(uuid_to_test, version=4):
 
 
 # Create a hash hex digest from string
-def hashstr(str):
+def hashstr(raw):
+    if type(raw) != type(""):
+        raw = f"{raw}"
     sha256 = hashlib.sha256()
-    sha256.update(str.encode("utf-8"))
+    sha256.update(raw.encode("utf-8"))
     return sha256.hexdigest().upper()
 
 
@@ -375,13 +380,16 @@ def debug_imports():
     sys.exit(6)
 
 
-
+class TimeoutRequestsSession(requests.Session):
+    def request(self, *args, **kwargs):
+        kwargs.setdefault("timeout", HTTP_TIMEOUT)
+        return super(TimeoutRequestsSession, self).request(*args, **kwargs)
 
 
 def requests_session():
     global _requests_session_instance
     if not _requests_session_instance:
-        _requests_session_instance = requests.Session()
+        _requests_session_instance = TimeoutRequestsSession()
         # fmt:off
         headers = {
               "User-Agent": "Mozilla/5.0 (Windows NT 6.1; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/40.0.2214.85 Safari/537.36"
@@ -392,3 +400,18 @@ def requests_session():
         # fmt:on
         _requests_session_instance.headers.update(headers)
     return _requests_session_instance
+
+
+
+def get_package_file_content(filename):
+    """Look for file relative to package root and return it's content"""
+    content=""
+    path: str = os.path.abspath(os.path.join(os.path.dirname(__file__), "../../"))
+    full_filename = f"{path}/{filename}"
+    if pkg_resources.resource_exists(__name__, filename):
+        content = pkg_resources.resource_string(__name__, filename).decode("utf-8").strip()
+    elif os.path.exists(full_filename):
+        content = read_file(full_filename)
+    else:
+        logger.warning(f"No content found for {full_filename}")
+    return content
